# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/kaskada/v1alpha/output.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaskada.kaskada.v1alpha import common_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$kaskada/kaskada/v1alpha/output.proto\x12\x17kaskada.kaskada.v1alpha\x1a$kaskada/kaskada/v1alpha/common.proto\"\xd3\x01\n\x11ObjectStoreOutput\x12>\n\tfile_type\x18\x01 \x01(\x0e\x32!.kaskada.kaskada.v1alpha.FileTypeR\x08\x66ileType\x12Y\n\x0coutput_paths\x18\x02 \x01(\x0b\x32\x36.kaskada.kaskada.v1alpha.ObjectStoreOutput.ResultPathsR\x0boutputPaths\x1a#\n\x0bResultPaths\x12\x14\n\x05paths\x18\x01 \x03(\tR\x05paths\"\r\n\x0bRedisOutput\"Y\n\x0cPulsarOutput\x12\x1b\n\ttopic_url\x18\x01 \x01(\tR\x08topicUrl\x12,\n\x12\x62roker_service_url\x18\x02 \x01(\tR\x10\x62rokerServiceUrlB\xfb\x01\n\x1b\x63om.kaskada.kaskada.v1alphaB\x0bOutputProtoP\x01ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\xa2\x02\x03KKX\xaa\x02\x17Kaskada.Kaskada.V1alpha\xca\x02\x17Kaskada\\Kaskada\\V1alpha\xe2\x02#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\xea\x02\x19Kaskada::Kaskada::V1alphab\x06proto3')



_OBJECTSTOREOUTPUT = DESCRIPTOR.message_types_by_name['ObjectStoreOutput']
_OBJECTSTOREOUTPUT_RESULTPATHS = _OBJECTSTOREOUTPUT.nested_types_by_name['ResultPaths']
_REDISOUTPUT = DESCRIPTOR.message_types_by_name['RedisOutput']
_PULSAROUTPUT = DESCRIPTOR.message_types_by_name['PulsarOutput']
ObjectStoreOutput = _reflection.GeneratedProtocolMessageType('ObjectStoreOutput', (_message.Message,), {

  'ResultPaths' : _reflection.GeneratedProtocolMessageType('ResultPaths', (_message.Message,), {
    'DESCRIPTOR' : _OBJECTSTOREOUTPUT_RESULTPATHS,
    '__module__' : 'kaskada.kaskada.v1alpha.output_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ObjectStoreOutput.ResultPaths)
    })
  ,
  'DESCRIPTOR' : _OBJECTSTOREOUTPUT,
  '__module__' : 'kaskada.kaskada.v1alpha.output_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ObjectStoreOutput)
  })
_sym_db.RegisterMessage(ObjectStoreOutput)
_sym_db.RegisterMessage(ObjectStoreOutput.ResultPaths)

RedisOutput = _reflection.GeneratedProtocolMessageType('RedisOutput', (_message.Message,), {
  'DESCRIPTOR' : _REDISOUTPUT,
  '__module__' : 'kaskada.kaskada.v1alpha.output_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.RedisOutput)
  })
_sym_db.RegisterMessage(RedisOutput)

PulsarOutput = _reflection.GeneratedProtocolMessageType('PulsarOutput', (_message.Message,), {
  'DESCRIPTOR' : _PULSAROUTPUT,
  '__module__' : 'kaskada.kaskada.v1alpha.output_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.PulsarOutput)
  })
_sym_db.RegisterMessage(PulsarOutput)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033com.kaskada.kaskada.v1alphaB\013OutputProtoP\001ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\242\002\003KKX\252\002\027Kaskada.Kaskada.V1alpha\312\002\027Kaskada\\Kaskada\\V1alpha\342\002#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\352\002\031Kaskada::Kaskada::V1alpha'
  _OBJECTSTOREOUTPUT._serialized_start=104
  _OBJECTSTOREOUTPUT._serialized_end=315
  _OBJECTSTOREOUTPUT_RESULTPATHS._serialized_start=280
  _OBJECTSTOREOUTPUT_RESULTPATHS._serialized_end=315
  _REDISOUTPUT._serialized_start=317
  _REDISOUTPUT._serialized_end=330
  _PULSAROUTPUT._serialized_start=332
  _PULSAROUTPUT._serialized_end=421
# @@protoc_insertion_point(module_scope)
